package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcBrandProjectMapper;
import com.ruoyi.oa.domain.CmcBrandProject;
import com.ruoyi.oa.service.ICmcBrandProjectService;

/**
 * cmc品牌项目Service业务层处理
 * 
 * @author cmc
 * @date 2024-04-29
 */
@Service
public class CmcBrandProjectServiceImpl implements ICmcBrandProjectService 
{
    @Autowired
    private CmcBrandProjectMapper cmcBrandProjectMapper;

    /**
     * 查询cmc品牌项目
     * 
     * @param projectId cmc品牌项目主键
     * @return cmc品牌项目
     */
    @Override
    public CmcBrandProject selectCmcBrandProjectByProjectId(String projectId)
    {
        return cmcBrandProjectMapper.selectCmcBrandProjectByProjectId(projectId);
    }

    /**
     * 查询cmc品牌项目列表
     * 
     * @param cmcBrandProject cmc品牌项目
     * @return cmc品牌项目
     */
    @Override
    public List<CmcBrandProject> selectCmcBrandProjectList(CmcBrandProject cmcBrandProject)
    {
        return cmcBrandProjectMapper.selectCmcBrandProjectList(cmcBrandProject);
    }

    /**
     * 新增cmc品牌项目
     * 
     * @param cmcBrandProject cmc品牌项目
     * @return 结果
     */
    @Override
    public int insertCmcBrandProject(CmcBrandProject cmcBrandProject)
    {
        return cmcBrandProjectMapper.insertCmcBrandProject(cmcBrandProject);
    }

    /**
     * 修改cmc品牌项目
     * 
     * @param cmcBrandProject cmc品牌项目
     * @return 结果
     */
    @Override
    public int updateCmcBrandProject(CmcBrandProject cmcBrandProject)
    {
        return cmcBrandProjectMapper.updateCmcBrandProject(cmcBrandProject);
    }

    /**
     * 批量删除cmc品牌项目
     * 
     * @param projectIds 需要删除的cmc品牌项目主键
     * @return 结果
     */
    @Override
    public int deleteCmcBrandProjectByProjectIds(String[] projectIds)
    {
        return cmcBrandProjectMapper.deleteCmcBrandProjectByProjectIds(projectIds);
    }

    /**
     * 删除cmc品牌项目信息
     * 
     * @param projectId cmc品牌项目主键
     * @return 结果
     */
    @Override
    public int deleteCmcBrandProjectByProjectId(String projectId)
    {
        return cmcBrandProjectMapper.deleteCmcBrandProjectByProjectId(projectId);
    }
}
